@@ -36,7 +36,6 @@
 #include "user_manager_debug.h"
 #include <KJob>
 #include <KIO/CopyJob>
-#include <KIconLoader>
 #include <KUser>
 #include <KI18n/klocalizedstring.h>
 
@@ -47,6 +46,10 @@ AccountInfo::AccountInfo(AccountModel* model, QWidget* parent, Qt::WindowFlags f
 {
     m_info->setupUi(this);
 
+    // ensure avatar user icon use correct device pixel ratio
+    const qreal dpr = qApp->devicePixelRatio();
+    m_model->setDpr(dpr);
+
     connect(m_info->username, &QLineEdit::textEdited, this, &AccountInfo::hasChanged);
     connect(m_info->realName, &QLineEdit::textEdited, this, &AccountInfo::hasChanged);
     connect(m_info->email, &QLineEdit::textEdited, this, &AccountInfo::hasChanged);
@@ -74,7 +77,7 @@ AccountInfo::AccountInfo(AccountModel* model, QWidget* parent, Qt::WindowFlags f
     menu->addAction(openAvatar);
     menu->addAction(editClear);
 
-    int iconSizeX = IconSize(KIconLoader::Dialog);
+    int iconSizeX = style()->pixelMetric(QStyle::PM_LargeIconSize);
     QSize iconSize(iconSizeX, iconSizeX);
     m_info->face->setIconSize(iconSize);
     m_info->face->setMinimumSize(iconSize);
@@ -137,19 +140,24 @@ bool AccountInfo::save()
 
     qCDebug(USER_MANAGER_LOG) << "Saving on Index: " << m_index.row();
     QList<AccountModel::Role> failed;
-    if (!m_model->setData(m_index, m_info->username->text(), AccountModel::Username)) {
+    if (m_infoToSave.contains(AccountModel::Username)  &&
+            !m_model->setData(m_index, m_infoToSave[AccountModel::Username], AccountModel::Username)) {
         failed.append(AccountModel::Username);
     }
-    if (!m_model->setData(m_index, m_info->realName->text(), AccountModel::RealName)) {
+    if (m_infoToSave.contains(AccountModel::RealName) &&
+            !m_model->setData(m_index, m_infoToSave[AccountModel::RealName], AccountModel::RealName)) {
         failed.append(AccountModel::RealName);
     }
-    if (!m_model->setData(m_index, m_info->email->text(), AccountModel::Email)) {
+    if (m_infoToSave.contains(AccountModel::Email) &&
+            !m_model->setData(m_index, m_infoToSave[AccountModel::Email], AccountModel::Email)) {
         failed.append(AccountModel::Email);
     }
-    if (!m_model->setData(m_index, m_info->administrator->isChecked(), AccountModel::Administrator)) {
+    if (m_infoToSave.contains(AccountModel::Administrator) &&
+            !m_model->setData(m_index, m_info->administrator->isChecked(), AccountModel::Administrator)) {
         failed.append(AccountModel::Administrator);
     }
-    if (!m_model->setData(m_index, m_info->automaticLogin->isChecked(), AccountModel::AutomaticLogin)) {
+    if (m_infoToSave.contains(AccountModel::AutomaticLogin) &&
+            !m_model->setData(m_index, m_info->automaticLogin->isChecked(), AccountModel::AutomaticLogin)) {
         failed.append(AccountModel::AutomaticLogin);
     }
     if (m_infoToSave.contains(AccountModel::Password)) {
@@ -449,7 +457,6 @@ void AccountInfo::avatarModelChanged(KJob* job)
 
 void AccountInfo::clearAvatar()
 {
-    QSize icon(IconSize(KIconLoader::Dialog), IconSize(KIconLoader::Dialog));
     m_info->face->setIcon(QIcon::fromTheme(QStringLiteral("user-identity")).pixmap(48, 48));
     m_infoToSave.insert(AccountModel::Face, QString());
     Q_EMIT changed(true);
