@@ -23,11 +23,13 @@
 #include "accounts_interface.h"
 #include "user_interface.h"
 
+#include <QApplication>
+#include <QRandomGenerator>
 #include <QIcon>
+#include <QStyle>
 
 #include "user_manager_debug.h"
 #include <KLocalizedString>
-#include <kiconloader.h>
 
 #include <KAuth/KAuthActionReply>
 #include <KAuth/KAuthExecuteJob>
@@ -145,11 +147,13 @@ QVariant AccountModel::data(const QModelIndex& index, int role) const
         case Qt::DecorationRole || AccountModel::Face:
         {
             QFile file(acc->iconFile());
-            int size = IconSize(KIconLoader::Dialog);
+            int size = QApplication::style()->pixelMetric(QStyle::PM_LargeIconSize);
             if (!file.exists()) {
                 return QIcon::fromTheme(QStringLiteral("user-identity")).pixmap(size, size);
             }
-            return QPixmap(file.fileName()).scaled(size, size, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+            auto pixMap = QPixmap(file.fileName()).scaled(static_cast<int>(size * m_dpr), static_cast<int>(size * m_dpr), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+            pixMap.setDevicePixelRatio(m_dpr);
+            return pixMap;
         }
         case AccountModel::RealName:
             return acc->realName();
@@ -205,8 +209,6 @@ bool AccountModel::setData(const QModelIndex& index, const QVariant& value, int
             }
             m_kEmailSettings.setSetting(KEMailSettings::RealName, value.toString());
 
-            m_dbus->UncacheUser(acc->userName()).waitForFinished();
-            m_dbus->CacheUser(acc->userName());
             emit dataChanged(index, index);
             return true;
         case AccountModel::Username:
@@ -297,7 +299,7 @@ QVariant AccountModel::newUserData(int role) const
         case Qt::DisplayRole || AccountModel::FriendlyName:
             return i18n("New User");
         case Qt::DecorationRole || AccountModel::Face:
-            return QIcon::fromTheme(QStringLiteral("list-add-user")).pixmap(IconSize(KIconLoader::Dialog), IconSize(KIconLoader::Dialog));
+            return QIcon::fromTheme(QStringLiteral("list-add-user"));
         case AccountModel::Created:
             return false;
     }
@@ -309,12 +311,16 @@ bool AccountModel::newUserSetData(const QModelIndex &index, const QVariant& valu
     AccountModel::Role role = static_cast<AccountModel::Role>(roleInt);
     m_newUserData[role] = value;
     QList<AccountModel::Role> roles = m_newUserData.keys();
-    if (!roles.contains(Username) || !roles.contains(RealName) || !roles.contains(Administrator)) {
+    if (!roles.contains(Username) || !roles.contains(RealName)) {
         return true;
     }
 
+    // defaults to non-administrator
+    int userType = 0;
+    if (m_newUserData.contains(Administrator)) {
+        userType = m_newUserData[Administrator].toBool();
+    }
 
-    int userType = m_newUserData[Administrator].toBool() ? 1 : 0;
     QDBusPendingReply <QDBusObjectPath > reply = m_dbus->CreateUser(m_newUserData[Username].toString(), m_newUserData[RealName].toString(), userType);
     reply.waitForFinished();
 
@@ -327,7 +333,6 @@ bool AccountModel::newUserSetData(const QModelIndex &index, const QVariant& valu
 
     m_newUserData.remove(Username);
     m_newUserData.remove(RealName);
-    m_newUserData.remove(Administrator);
 
     //If we don't have anything else to set just return
     if (m_newUserData.isEmpty()) {
@@ -490,13 +495,13 @@ const QString AccountModel::accountPathForUid(uint uid) const
 
 QString AccountModel::cryptPassword(const QString& password) const
 {
-    QString cryptedPassword;
     QByteArray alpha = "0123456789ABCDEFGHIJKLMNOPQRSTUVXYZ"
                        "abcdefghijklmnopqrstuvxyz./";
     QByteArray salt("$6$");//sha512
     int len = alpha.count();
+    auto *generator = QRandomGenerator::global();
     for(int i = 0; i < 16; i++){
-        salt.append(alpha.at((qrand() % len)));
+        salt.append(alpha.at(generator->bounded(len)));
     }
 
     return QString::fromUtf8(crypt(password.toUtf8().constData(), salt.constData()));
@@ -539,4 +544,8 @@ QDebug operator<<(QDebug debug, AccountModel::Role role)
     return debug;
 }
 
+void AccountModel::setDpr(qreal dpr) {
+    m_dpr = dpr;
+}
+
 
